#!/usr/bin/env python3
# -*- coding:utf-8 -*-⏎

from __future__ import print_function
from image import *
from fs import *

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~4~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~8
def test():
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~4~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~8
    src_fi=FileInfo("a.jpg")
    dst_fn="a.thumb.jpg"
    size = (120,100)
    print("a.jpg")
    if save_thumb(src_fi, dst_fn, size):
        print("ok")
    else:
        print("no")

    src_fi=FileInfo("b.jpg")
    dst_fn="b.thumb.jpg"
    size = (120,100)
    print("b.jpg")
    if save_thumb(src_fi, dst_fn, size):
        print("ok")
    else:
        print("no")

    src_fi=FileInfo("c.jpg")
    dst_fn="c.thumb.jpg"
    print("c.jpg")
    size = (120,100)
    if save_thumb(src_fi, dst_fn, size):
        print("ok")
    else:
        print("no")

    src_fi=FileInfo("a.png")
    dst_fn="a.thumb.png.jpg"
    print("a.png")
    size = (120,100)
    if save_thumb(src_fi, dst_fn, size):
        print("ok")
    else:
        print("no")

    src_fi=FileInfo("c.png")
    dst_fn="c.thumb.png.jpg"
    size = (120,100)
    if save_thumb(src_fi, dst_fn, size):
        print("ok")
    else:
        print("no")

if __name__ == "__main__": test()
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~4~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~8



from PIL import Image
from PIL import ExifTags

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~4~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~8
def save_thumb(src_fi, dst_fn, size, verbose=1):
    try:
        img = Image.open(src_fi.full_fn)
    except Exception as e:
        if verbose>=1:
            print(e)
        return False

    #if src_fi.ext == "jpg" or src_fi.ext == "jpeg":
    try:
        exif_dict = img._getexif()
        if exif_dict:

            # rotate
            orientation = None
            for k, v in ExifTags.TAGS.items() : 
                if v == "Orientation":
                    orientation = k
                    break
            if orientation:
                if exif_dict[orientation] == 3 : 
                    img=img.rotate(180, expand=True)
                elif exif_dict[orientation] == 6 : 
                    img=img.rotate(270, expand=True)
                elif exif_dict[orientation] == 8 : 
                    img=img.rotate(90, expand=True)
                else:
                    pass
    except Exception as e:
        #print(e)
        pass

    img = img.convert("RGB")

    # save
    try:
        img.thumbnail( size, Image.ANTIALIAS )
        img.save(dst_fn, "JPEG")
    except Exception as e:
        if verbose>=1:
            print("Save fail: %s" % e)
        return False

    return True
